@@ -8,6 +8,7 @@ from MorphologicalAnalysis.MorphologicalParse import MorphologicalParse
 from MorphologicalAnalysis.MorphologicalTag import MorphologicalTag
 from NamedEntityRecognition.Gazetteer import Gazetteer
 from NamedEntityRecognition.NamedEntityType import NamedEntityType
+from NamedEntityRecognition.Slot import Slot
 from PropBank.Argument import Argument
 
 import re
@@ -24,6 +25,8 @@ class AnnotatedWord(Word):
     __frameElement: FrameElement
     __shallowParse: str
     __universalDependency: UniversalDependencyRelation
+    __slot: Slot
+
 
     def __init__(self, word: str, layerType=None):
         """
@@ -43,6 +46,7 @@ class AnnotatedWord(Word):
         self.__frameElement = None
         self.__shallowParse = None
         self.__universalDependency = None
+        self.__slot = None
         if layerType is None:
             splitLayers = re.compile("[{}]").split(word)
             for layer in splitLayers:
@@ -69,6 +73,8 @@ class AnnotatedWord(Word):
                     self.__shallowParse = layerValue
                 elif layerType == "semantics":
                     self.__semantic = layerValue
+                elif layerType == "slot":
+                    self.__slot = Slot(layerValue)
                 elif layerType == "universalDependency":
                     values = layerValue.split("$")
                     self.__universalDependency = UniversalDependencyRelation(int(values[0]), values[1])
@@ -111,6 +117,8 @@ class AnnotatedWord(Word):
             result = result + "{propbank=" + self.__argument.__str__() + "}"
         if self.__frameElement is not None:
             result = result + "{framenet=" + self.__frameElement.__str__() + "}"
+        if self.__slot is not None:
+            result = result + "{slot=" + self.__slot.__str__() + "}"
         if self.__shallowParse is not None:
             result = result + "{shallowParse=" + self.__shallowParse + "}"
         if self.__universalDependency is not None:
@@ -153,6 +161,9 @@ class AnnotatedWord(Word):
         elif viewLayerType == ViewLayerType.FRAMENET:
             if self.__frameElement is not None:
                 return self.__frameElement.__str__()
+        elif viewLayerType == ViewLayerType.SLOT:
+            if self.__slot is not None:
+                return self.__slot.__str__()
         elif viewLayerType == ViewLayerType.DEPENDENCY:
             if self.__universalDependency is not None:
                 return self.__universalDependency.to().__str__() + "$" + self.__universalDependency.__str__()
@@ -303,6 +314,31 @@ class AnnotatedWord(Word):
         else:
             self.__frameElement = None
 
+    def getSlot(self) -> Slot:
+        """
+        Returns the slot layer of the word.
+
+        RETURNS
+        -------
+        Slot
+            Slot tag of the word.
+        """
+        return self.__slot
+
+    def setSlot(self, slot: str):
+        """
+        Sets the slot layer of the word.
+
+        PARAMETERS
+        ----------
+        slot : str
+            New slot tag of the word.
+        """
+        if slot is not None:
+            self.__slot = Slot(slot)
+        else:
+            self.__slot = None
+
     def getShallowParse(self) -> str:
         """
         Returns the shallow parse layer of the word.
